package com.yijia.station.controller;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.*;

import com.yijia.common.config.YiJiaConfig;
import com.yijia.common.core.domain.entity.SysDept;
import com.yijia.common.core.domain.model.LoginUser;
import com.yijia.common.exception.CustomException;
import com.yijia.common.utils.SecurityUtils;
import com.yijia.station.service.IStationDeviceManageService;
import com.yijia.station.utils.FeiEPrinterUtil;
import com.yijia.system.service.ISysDeptService;
import com.yijia.system.service.ISysUserService;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.streaming.SXSSFWorkbook;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;
import com.yijia.station.domain.PayOrder;
import com.yijia.station.service.IPayOrderService;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.common.core.page.TableDataInfo;

/**
 * 订单支付Controller
 *
 * @author yijia
 * @date 2020-12-10
 */
@RestController
@RequestMapping("/station/order")
public class PayOrderController extends BaseController
{
    private static final Logger log = LoggerFactory.getLogger(PayOrderController.class);
    @Autowired
    private IPayOrderService payOrderService;
    @Autowired
    private ISysDeptService deptService;

    @Autowired
    private IStationDeviceManageService stationDeviceManageService;

    /**
     * 查询订单支付列表
     */
    @GetMapping("/list")
    public TableDataInfo list(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        startPage();
        payOrder.setStatus("1");
        List<PayOrder> payOrderList = payOrderService.selectPayOrderList(payOrder);
        return getDataTable(payOrderList);
    }
    /**
     * 关联用户查询订单支付列表
     */
    @GetMapping("/selectUserPayOrderList")
    public TableDataInfo selectUserPayOrderList(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        startPage();
        payOrder.setStatus("1");
        List<PayOrder> payOrderList = payOrderService.selectUserPayOrderList(payOrder);
        return getDataTable(payOrderList);
    }


    @GetMapping("/selectPayOrderList")
    public TableDataInfo selectPayOrderList(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        startPage();
        payOrder.setStatus("1");
        List<PayOrder> payOrderList = payOrderService.selectPayOrderList(payOrder);
        return getDataTable(payOrderList);
    }
    /**
     * 查询订单支付列表
     */
    @GetMapping("/listInfo")
    public TableDataInfo listInfo(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setOrderType("1");
        payOrder.setStatus("1");
        List<PayOrder> payOrderList = payOrderService.selectPayOrderList(payOrder);
        return getTable(payOrderList);
    }

    /**
     * 查询总金额，总升数
     * @param payOrder
     * @return
     */
    @GetMapping("/selectDaySources")
    public AjaxResult selectDaySources(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        PayOrder order = payOrderService.selectDaySources(payOrder);
        return AjaxResult.success(order);
    }

    /***
     * 根据油品分类，查询油品的总金额，总升数
     * @param payOrder
     * @return
     */
    @GetMapping("/selectOilTypeSources")
    public TableDataInfo selectOilTypeSources(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder> orderList = payOrderService.selectOilTypeSources(payOrder);
        return getTable(orderList);
    }

    /***
     * 根据油品分类，查询油品的总金额，总升数
     * @param payOrder
     * @return
     */
    @GetMapping("/dayOilTypeSources")
    public TableDataInfo dayOilTypeSources(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder> orderList = payOrderService.dayOilTypeSources(payOrder);
        return getTable(orderList);
    }
    /***
     * 根据油品分类，查询油品的总金额，总升数
     * @param payOrder
     * @return
     */
    @GetMapping("/selectOverViewData")
    public AjaxResult selectOverViewData(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        PayOrder order = payOrderService.selectOverViewData(payOrder);
        return AjaxResult.success(order);
    }

    /**
     * 日报数据详细
     */
    @GetMapping("/selectDayReportDetail")
    public TableDataInfo selectDayReportDetail(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        //默认当前登陆人的ID 5冯总油站
        startPage();
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.selectDayReport(payOrder);
        return getDataTable(orderList);
    }

    /***
     * 根据油品分类，查询油品的总金额，总升数
     * @param payOrder
     * @return
     */
    @GetMapping("/selectDayReport")
    public TableDataInfo selectDayReport(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
       List<PayOrder>  orderList = payOrderService.selectDayReport(payOrder);
        return getTable(orderList);
    }

    /**
     * 导出订单支付列表
     */
    @Log(title = "订单支付", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder> payOrderList = payOrderService.selectPayOrderExport(payOrder);
        ExcelUtil<PayOrder> util = new ExcelUtil<PayOrder>(PayOrder.class);
        return util.exportExcel(payOrderList, "order");
    }


    /**
     * 获取订单支付详细信息
     */
    @GetMapping(value = "/{orderId}")
    public AjaxResult getInfo(@PathVariable("orderId") Long orderId)
    {
        return AjaxResult.success(payOrderService.selectPayOrderById(orderId));
    }

    /**
     * 获取92号汽油数据
     * @param payOrder
     * @return
     */
    @GetMapping("/listQydata92")
    public TableDataInfo listQydata92(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setOilName("92#");
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listQydata(payOrder);
        return getTable(orderList);
    }
    /**
     * 获取95号汽油数据
     * @param payOrder
     * @return
     */
    @GetMapping("/listQydata95")
    public TableDataInfo listQydata95(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setOilName("95#");
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listQydata(payOrder);
        return getTable(orderList);
    }
    /**
     * 获取97号汽油数据
     * @param payOrder
     * @return
     */
    @GetMapping("/listQydata98")
    public TableDataInfo listQydata98(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setOilName("98#");
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listQydata(payOrder);
        return getTable(orderList);
    }

    /**
     * 获取97号汽油数据
     * @param payOrder
     * @return
     */
    @GetMapping("/listQydata20")
    public TableDataInfo listQydata20(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setOilName("-20#");
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listQydata(payOrder);
        return getTable(orderList);
    }
    /**
     * 获取97号汽油数据
     * @param payOrder
     * @return
     */
    @GetMapping("/listQydata0")
    public TableDataInfo listQydata0(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setOilName("0#");
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listQydata(payOrder);
        return getTable(orderList);
    }
    /**
     * 获取97号汽油数据
     * @param payOrder
     * @return
     */
    @GetMapping("/listQydata10")
    public TableDataInfo listQydata10(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setOilName("-10#");
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listQydata(payOrder);
        return getTable(orderList);
    }
    /**
     * 获取x轴数据
     * @param payOrder
     * @return
     */
    @GetMapping("/listXdata")
    public TableDataInfo listXdata(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listXdata(payOrder);
        return getTable(orderList);
    }
    /**
     * 查询油站第一笔订单的数据
     */
    @GetMapping("/getPayOrderInfoMin")
    public AjaxResult getPayOrderInfoMin(PayOrder payOrder)
    {
        if(payOrder.getStationId() ==null) {
            LoginUser currentUser = SecurityUtils.getLoginUser();
            payOrder.setStationId(currentUser.getUser().getDeptId());
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        return  AjaxResult.success(payOrderService.getPayOrderInfoMin(payOrder));
    }
    /**
     * 新增订单支付
     */
    @Log(title = "订单支付", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PayOrder payOrder)
    {
        return toAjax(payOrderService.insertPayOrder(payOrder));
    }

    /**
     * 修改订单支付
     */
    @Log(title = "订单支付", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PayOrder payOrder)
    {
        return toAjax(payOrderService.updatePayOrder(payOrder));
    }

    /**
     * 删除订单支付
     */
    @Log(title = "订单支付", businessType = BusinessType.DELETE)
	@DeleteMapping("/{orderIds}")
    public AjaxResult remove(@PathVariable Long[] orderIds)
    {
        return toAjax(payOrderService.deletePayOrderByIds(orderIds));
    }

    /**
     * 查询订单支付列表
     */
    @GetMapping("/LNGDeptList")
    public TableDataInfo LNGDeptList(PayOrder payOrder)
    {
        List<String> list = deptService.levelDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        startPage();
        payOrder.setStatus("1");
        List<PayOrder> payOrderList = payOrderService.LNGDeptList(payOrder);
        return getDataTable(payOrderList);
    }
    /**
     * 查询订单支付列表
     */
    @GetMapping("/LNGlist")
    public TableDataInfo LNGlist(PayOrder payOrder)
    {
        List<String> list = deptService.levelLngDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        startPage();
        payOrder.setStatus("1");
        List<PayOrder> payOrderList = payOrderService.selectLNGPayOrderExport(payOrder);
        return getDataTable(payOrderList);
    }

    @Log(title = "导出LNG", businessType = BusinessType.EXPORT)
    @GetMapping("/LNGExport")
    public AjaxResult LNGExport(PayOrder payOrder)
    {
        List<String> list = deptService.levelLngDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setStatus("1");
        List<PayOrder> payOrderList = payOrderService.selectLNGPayOrderExport(payOrder);
        AjaxResult ss = exportExcel(payOrderList, "导出订单信息");
        return ss;
    }

    private AjaxResult exportExcel(List<PayOrder> payOrderList, String sheetName) {
        OutputStream out = null;
        Workbook wb= new SXSSFWorkbook(500);
        try
        {
            Sheet sheet = wb.createSheet(sheetName);
            sheet.setDefaultColumnWidth(20);//默认列宽20
            CellStyle style = wb.createCellStyle();
            CreationHelper createHelper = wb.getCreationHelper();
            style.setDataFormat(createHelper.createDataFormat().getFormat("yyyy-mm-dd hh:mm:ss"));
            int rows =payOrderList.size()+1;
            Cell cell =null;
            Row row =null;
            for (int i = 0; i < rows; i++) {
                if(i == 0) {
                    row = sheet.createRow(i);
                    cell = row.createCell(0);
                    cell.setCellValue("油站名称");
                    cell.setCellStyle(style);
                    cell = row.createCell(1);
                    cell.setCellValue("油品");
                    cell.setCellStyle(style);
                    cell = row.createCell(2);
                    cell.setCellValue("订单号");
                    cell.setCellStyle(style);
                    cell = row.createCell(3);
                    cell.setCellValue("枪标价");
                    cell.setCellStyle(style);
                    cell = row.createCell(4);
                    cell.setCellValue("结算价");
                    cell.setCellStyle(style);
                    cell = row.createCell(5);
                    cell.setCellValue("司机价");
                    cell.setCellStyle(style);
                    cell = row.createCell(6);
                    cell.setCellValue("升数");
                    cell.setCellStyle(style);
                    cell = row.createCell(7);
                    cell.setCellValue("应付金额");
                    cell.setCellStyle(style);
                    cell = row.createCell(8);
                    cell.setCellValue("结算金额");
                    cell.setCellStyle(style);
                    cell = row.createCell(9);
                    cell.setCellValue("司机金额");
                    cell.setCellStyle(style);
                    cell = row.createCell(10);
                    cell.setCellValue("支付时间");
                    cell.setCellStyle(style);
                    cell = row.createCell(11);
                    cell.setCellValue("手机号");
                    cell.setCellStyle(style);
                }else {
                    row = sheet.createRow(i);
                    int j =i-1;
                    cell = row.createCell(0);
                    cell.setCellValue(payOrderList.get(j).getStationName());
                    cell.setCellStyle(style);
                    cell = row.createCell(1);
                    cell.setCellValue(payOrderList.get(j).getOilName());
                    cell.setCellStyle(style);
                    cell = row.createCell(2);
                    cell.setCellValue(payOrderList.get(j).getOrderNo());
                    cell.setCellStyle(style);
                    cell = row.createCell(3);
                    cell.setCellValue(payOrderList.get(j).getOilPirce()+"");
                    cell.setCellStyle(style);
                    cell = row.createCell(4);
                    if(payOrderList.get(j).getSellOilPrice()!=null){
                        cell.setCellValue(payOrderList.get(j).getSellOilPrice()+"");
                    }else{
                        cell.setCellValue("0");
                    }
                    cell.setCellStyle(style);
                    cell = row.createCell(5);
                    if(payOrderList.get(j).getDriverOilPrice()!=null){
                        cell.setCellValue(payOrderList.get(j).getDriverOilPrice()+"");
                    }else{
                        cell.setCellValue("0");
                    }
                    cell.setCellStyle(style);
                    cell = row.createCell(6);
                    if(payOrderList.get(j).getOrderLiters()!=null){
                        cell.setCellValue(payOrderList.get(j).getOrderLiters()+"");
                    }else{
                        cell.setCellValue("0");
                    }
                    cell.setCellStyle(style);
                    cell = row.createCell(7);
                    if(payOrderList.get(j).getReceivableAmt()!=null){
                        cell.setCellValue(payOrderList.get(j).getReceivableAmt()+"");
                    }else{
                        cell.setCellValue("0");
                    }
                    cell.setCellStyle(style);
                    cell = row.createCell(8);
                    if(payOrderList.get(j).getSellAmt()!=null){
                        cell.setCellValue(payOrderList.get(j).getSellAmt()+"");
                    }else{
                        cell.setCellValue("0");
                    }
                    cell.setCellStyle(style);
                    cell = row.createCell(9);
                    if(payOrderList.get(j).getAmt()!=null){
                        cell.setCellValue(payOrderList.get(j).getAmt()+"");
                    }else{
                        cell.setCellValue("0");
                    }
                    cell.setCellStyle(style);
                    cell = row.createCell(10);
                    cell.setCellValue(payOrderList.get(j).getPayDate());
                    cell.setCellStyle(style);
                    cell = row.createCell(11);
                    cell.setCellValue(payOrderList.get(j).getMobilePhone());
                    cell.setCellStyle(style);
                }
            }
            String filename = encodingFilename(sheetName);
            out = new FileOutputStream(getAbsoluteFile(filename));
            wb.write(out);
            return AjaxResult.success(filename);
        }
        catch (Exception e)
        {
            log.error("导出Excel异常{}", e.getMessage());
            throw new CustomException("导出Excel失败，请联系网站管理员！");
        }
        finally
        {
            if (wb != null)
            {
                try
                {
                    wb.close();
                }
                catch (IOException e1)
                {
                    e1.printStackTrace();
                }
            }
            if (out != null)
            {
                try
                {
                    out.close();
                }
                catch (IOException e1)
                {
                    e1.printStackTrace();
                }
            }
        }
    }
    private String encodingFilename(String filename) {
        filename = UUID.randomUUID().toString() + "_" + filename + ".xlsx";
        return filename;
    }
    public String getAbsoluteFile(String filename)
    {
        String downloadPath = YiJiaConfig.getDownloadPath() + filename;
        File desc = new File(downloadPath);
        if (!desc.getParentFile().exists())
        {
            desc.getParentFile().mkdirs();
        }
        return downloadPath;
    }

    @Log(title = "导出LNG站点", businessType = BusinessType.EXPORT)
    @GetMapping("/LNGDeptExport")
    public AjaxResult LNGDeptExport(PayOrder payOrder)
    {
        List<String> list = deptService.levelLngDeptList(payOrder.getLevelId());
        if(list!=null && list.size()>0){
            payOrder.setStationIdList(list);
            payOrder.setStationId(null);
        }
        payOrder.setStatus("1");
        List<PayOrder> payOrderList = payOrderService.LNGDeptList(payOrder);
        AjaxResult ss = exportDeptExcel(payOrderList, "导出订单信息");
        return ss;
    }

    private AjaxResult exportDeptExcel(List<PayOrder> payOrderList, String sheetName) {
        OutputStream out = null;
        Workbook wb= new SXSSFWorkbook(500);
        try
        {
            Sheet sheet = wb.createSheet(sheetName);
            sheet.setDefaultColumnWidth(20);//默认列宽20
            CellStyle style = wb.createCellStyle();
            CreationHelper createHelper = wb.getCreationHelper();
            style.setDataFormat(createHelper.createDataFormat().getFormat("yyyy-mm-dd hh:mm:ss"));
            int rows =payOrderList.size()+1;
            Cell cell =null;
            Row row =null;
            for (int i = 0; i < rows; i++) {
                if(i == 0) {
                    row = sheet.createRow(i);
                    cell = row.createCell(0);
                    cell.setCellValue("油站名称");
                    cell.setCellStyle(style);
                    cell = row.createCell(1);
                    cell.setCellValue("订单号");
                    cell.setCellStyle(style);
                    cell = row.createCell(2);
                    cell.setCellValue("油品");
                    cell.setCellStyle(style);
                    cell = row.createCell(3);
                    cell.setCellValue("枪标价");
                    cell.setCellStyle(style);
                    cell = row.createCell(4);
                    cell.setCellValue("结算价");
                    cell.setCellStyle(style);
                    cell = row.createCell(5);
                    cell.setCellValue("升数");
                    cell.setCellStyle(style);
                    cell = row.createCell(6);
                    cell.setCellValue("应付金额");
                    cell.setCellStyle(style);
                    cell = row.createCell(7);
                    cell.setCellValue("结算金额");
                    cell.setCellStyle(style);
                    cell = row.createCell(8);
                    cell.setCellValue("结算优惠金额");
                    cell.setCellStyle(style);
                    cell = row.createCell(9);
                    cell.setCellValue("支付时间");
                    cell.setCellStyle(style);
                    cell = row.createCell(10);
                    cell.setCellValue("手机号");
                    cell.setCellStyle(style);
                }else {
                    row = sheet.createRow(i);
                    int j =i-1;
                    cell = row.createCell(0);
                    cell.setCellValue(payOrderList.get(j).getStationName());
                    cell.setCellStyle(style);
                    cell = row.createCell(1);
                    cell.setCellValue(payOrderList.get(j).getOrderNo());
                    cell.setCellStyle(style);
                    cell = row.createCell(2);
                    cell.setCellValue(payOrderList.get(j).getOilName());
                    cell.setCellStyle(style);
                    cell = row.createCell(3);
                    cell.setCellValue(payOrderList.get(j).getOilPirce()+"");
                    cell.setCellStyle(style);
                    cell = row.createCell(4);
                    if(payOrderList.get(j).getSellOilPrice()!=null){
                        cell.setCellValue(payOrderList.get(j).getSellOilPrice()+"");
                    }else{
                        cell.setCellValue("0");
                    }
                    cell.setCellStyle(style);
                    cell = row.createCell(5);
                    cell.setCellValue(payOrderList.get(j).getOrderLiters() + "");
                    cell.setCellStyle(style);
                    cell = row.createCell(6);
                    if(payOrderList.get(j).getReceivableAmt()!=null){
                        cell.setCellValue(payOrderList.get(j).getReceivableAmt()+"");
                    }else{
                        cell.setCellValue("0");
                    }
                    cell.setCellStyle(style);
                    cell = row.createCell(7);
                    if(payOrderList.get(j).getSellAmt()!=null){
                        cell.setCellValue(payOrderList.get(j).getSellAmt()+"");
                    }else{
                        cell.setCellValue("0");
                    }
                    cell.setCellStyle(style);
                    cell = row.createCell(8);
                    if(payOrderList.get(j).getSellDiscountAmt()!=null){
                        cell.setCellValue(payOrderList.get(j).getSellDiscountAmt()+"");
                    }else{
                        cell.setCellValue("0");
                    }
                    cell.setCellStyle(style);
                    cell = row.createCell(9);
                    cell.setCellValue(payOrderList.get(j).getPayDate());
                    cell.setCellStyle(style);
                    cell = row.createCell(10);
                    cell.setCellValue(payOrderList.get(j).getMobilePhone());
                    cell.setCellStyle(style);
                }
            }
            String filename = encodingFilename(sheetName);
            out = new FileOutputStream(getAbsoluteFile(filename));
            wb.write(out);
            return AjaxResult.success(filename);
        }
        catch (Exception e)
        {
            log.error("导出Excel异常{}", e.getMessage());
            throw new CustomException("导出Excel失败，请联系网站管理员！");
        }
        finally
        {
            if (wb != null)
            {
                try
                {
                    wb.close();
                }
                catch (IOException e1)
                {
                    e1.printStackTrace();
                }
            }
            if (out != null)
            {
                try
                {
                    out.close();
                }
                catch (IOException e1)
                {
                    e1.printStackTrace();
                }
            }
        }
    }

    /**
     * 补打订单信息
     */
    @Log(title = "补打订单小票", businessType = BusinessType.OTHER)
    @GetMapping("/printOrderInfo")
    public AjaxResult printOrderInfo(PayOrder payOrder){
        int i =0;
        DateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        if(payOrder.getOrderId() !=null){
            String content1 ="";
            String content2 ="" ;
            PayOrder order = payOrderService.selectPayOrderById(payOrder.getOrderId());
            if(order!=null){
                String  paytype ="";
                String  phoneNumber ="";
                if(order.getCustomerPhone()!=null ){
                    phoneNumber = order.getCustomerPhone().replaceAll("(\\w{3})\\w*(\\w{4})", "$1****$2");
                }
                if(order.getPayType().equals("wx")){
                    paytype="微信";
                }else if(order.getPayType().equals("dzk")){
                    paytype="电子卡";
                }else if(order.getPayType().equals("zfb")){
                    paytype="支付宝";
                }else if(order.getPayType().equals("xj")){
                    paytype="现金";
                }
                content1 = "<CB>油品订单--顾客联</CB><BR>";
                content1 += "<BR>";
                content1 += "--------------------------------<BR>";
                content1 += "<BR>";
                content1 += "<BOLD><B>原价： "+order.getReceivableAmt()+" 元</B></BOLD><BR>";
                content1 += "订单号："+order.getOrderNo()+" <BR>";
                content1 += "支付方式： "+paytype+" <BR>";
                content1 += "下单时间："+dateFormat.format(order.getCreatedDate())+" <BR>";
                content1 += "付款时间："+dateFormat.format(order.getPayDate())+" <BR>";
                content1 += "油站："+order.getStationName()+"  <BR>";
                content1 += "油枪："+order.getOilGun()+"号枪<BR>";
                if(order.getOilType()!=null && !order.getOilType().equals("3")){
                    content1 += "油品： "+order.getOilName()+"  <BR>";
                    content1 += "油量： "+order.getOrderLiters()+"  升<BR>";
                    content1 += "单价： "+order.getOilPirce()+" L/元<BR>";
                    content1 += "优惠： "+order.getDiscountAmt()+" 元<BR>";
                }
                content1 += "支付： "+order.getAmt()+" 元<BR>";
                content1 += "手机号： "+phoneNumber +" <BR>";
                content1 += "<BR>";

                content2 = "<CB>油品订单--商户联</CB><BR>";
                content2 += "<BR>";
                content2 += "--------------------------------<BR>";
                content2 += "<BR>";
                content2 += "<BOLD><B>原价： "+order.getReceivableAmt()+" 元</B></BOLD><BR>";
                content2 += "订单号："+order.getOrderNo()+"  <BR>";
                content2 += "支付方式： "+paytype+" <BR>";
                content2 += "下单时间："+dateFormat.format(order.getCreatedDate())+" <BR>";
                content2 += "付款时间："+dateFormat.format(order.getPayDate())+" <BR>";
                content2 += "油站："+order.getStationName()+"  <BR>";
                content2 += "油枪："+order.getOilGun()+"号枪<BR>";
                if(order.getOilType()!=null && !order.getOilType().equals("3")){
                    content2 += "油品： "+order.getOilName()+"  <BR>";
                    content2 += "油量： "+order.getOrderLiters()+"  升<BR>";
                    content2 += "单价： "+order.getOilPirce()+" L/元<BR>";
                    content2 += "优惠： "+order.getDiscountAmt()+" 元<BR>";
                }
                content2 += "支付： "+order.getAmt()+" 元<BR>";
                content2 += "手机号： "+phoneNumber +" <BR>";
                content2 += "<BR>";
            }
            Map params  =new HashMap();
            params.put("stationId", order.getStationId());
            params.put("deviceType", "1");
            Map mp  = stationDeviceManageService.getPrinterSnByStationId(params);
           SysDept dept=  deptService.selectDeptById(order.getStationId());
            if(mp!=null&&mp.containsKey("device_no") && mp.get("device_no")!= null && mp.get("device_no")!=""){
                String sn = mp.get("device_no").toString();
                if(dept!=null && dept.getPrintSetting()!=null&&dept.getPrintSetting().equals("1") &&content1!=null){
                    FeiEPrinterUtil.printReceipt(sn,content1);
                    i=1;
                    logger.info("客户联打印成功");
                }else if(dept!=null && dept.getPrintSetting()!=null&&dept.getPrintSetting().equals("2")&&content2!=null){
                    FeiEPrinterUtil.printReceipt(sn,content2);
                    i=1;
                    logger.info("商户联打印成功");
                }else if(dept!=null && dept.getPrintSetting()!=null&&dept.getPrintSetting().equals("3")&&content1!=null&&content2!=null){
                    FeiEPrinterUtil.printReceipt(sn, content1+content2);
                    i=1;
                    logger.info("客户联和商户联打印成功");
                }else {
                    i=0;
                    logger.info("打印失败");
                }
            }else {
                logger.info("请正确配置打印机");
                i=2;
            }
        }
        return toAjaxee(i);
    }
}
