package com.yijia.station.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;
import com.yijia.station.domain.StationSettlementPriceAdjust;
import com.yijia.station.service.IStationSettlementPriceAdjustService;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.common.core.page.TableDataInfo;

/**
 * 结算价格，司机价格优惠调整Controller
 *
 * @author yijia
 * @date 2021-07-14
 */
@RestController
@RequestMapping("/station/settlementPriceAdjust")
public class StationSettlementPriceAdjustController extends BaseController
{
    @Autowired
    private IStationSettlementPriceAdjustService stationSettlementPriceAdjustService;

    /**
     * 查询结算价格，司机价格优惠调整列表
     */
    @GetMapping("/list")
    public TableDataInfo list(StationSettlementPriceAdjust stationSettlementPriceAdjust)
    {
        startPage();
        List<StationSettlementPriceAdjust> list = stationSettlementPriceAdjustService.selectStationSettlementPriceAdjustList(stationSettlementPriceAdjust);
        return getDataTable(list);
    }

    /**
     * 导出结算价格，司机价格优惠调整列表
     */
    @Log(title = "结算价格，司机价格优惠调整", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(StationSettlementPriceAdjust stationSettlementPriceAdjust)
    {
        List<StationSettlementPriceAdjust> list = stationSettlementPriceAdjustService.selectStationSettlementPriceAdjustList(stationSettlementPriceAdjust);
        ExcelUtil<StationSettlementPriceAdjust> util = new ExcelUtil<StationSettlementPriceAdjust>(StationSettlementPriceAdjust.class);
        return util.exportExcel(list, "adjust");
    }

    /**
     * 获取结算价格，司机价格优惠调整详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return AjaxResult.success(stationSettlementPriceAdjustService.selectStationSettlementPriceAdjustById(id));
    }

    /**
     * 新增结算价格，司机价格优惠调整
     */
    @Log(title = "结算价格，司机价格优惠调整", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StationSettlementPriceAdjust stationSettlementPriceAdjust)
    {
        return toAjax(stationSettlementPriceAdjustService.insertStationSettlementPriceAdjust(stationSettlementPriceAdjust));
    }

    /**
     * 修改结算价格，司机价格优惠调整
     */
    @Log(title = "结算价格，司机价格优惠调整", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StationSettlementPriceAdjust stationSettlementPriceAdjust)
    {
        return toAjax(stationSettlementPriceAdjustService.updateStationSettlementPriceAdjust(stationSettlementPriceAdjust));
    }

    /**
     * 删除结算价格，司机价格优惠调整
     */
    @Log(title = "结算价格，司机价格优惠调整", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(stationSettlementPriceAdjustService.deleteStationSettlementPriceAdjustByIds(ids));
    }
}
