package com.yijia.station.controller;

import java.util.ArrayList;
import java.util.List;

import com.yijia.common.core.domain.entity.SysDept;
import com.yijia.common.core.domain.model.LoginUser;
import com.yijia.common.utils.DateUtils;
import com.yijia.common.utils.SecurityUtils;
import com.yijia.station.domain.StationSettlementPriceAdjust;
import com.yijia.station.service.IStationSettlementPriceAdjustService;
import com.yijia.system.service.ISysDeptService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;
import com.yijia.station.domain.StationSettlementPrice;
import com.yijia.station.service.IStationSettlementPriceService;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.common.core.page.TableDataInfo;

/**
 * 结算价格，司机价格Controller
 *
 * @author yijia
 * @date 2021-07-13
 */
@RestController
@RequestMapping("/station/settlementPrice")
public class StationSettlementPriceController extends BaseController
{
    @Autowired
    private IStationSettlementPriceService stationSettlementPriceService;
    @Autowired
    private ISysDeptService deptService;
    @Autowired
    private IStationSettlementPriceAdjustService stationSettlementPriceAdjustService;
    /**
     * 查询结算价格，司机价格列表
     */

    @GetMapping("/list")
    public TableDataInfo list(StationSettlementPrice stationSettlementPrice)
    {
       // startPage();
        LoginUser currentUser = SecurityUtils.getLoginUser();
        List<StationSettlementPrice> pircelist =new ArrayList<>();
        if(currentUser.getUser().getDept().getJiBie()!=0){
            SysDept dept =new SysDept();
            List<String> list = deptService.selectdeptInfoList(dept);
            if(list!=null && list.size()>0){
                stationSettlementPrice.setStationIdList(list);
                stationSettlementPrice.setStationId(null);
            }
            List<StationSettlementPrice> settlementPriceList = stationSettlementPriceService.selectStationSettlementPriceList(stationSettlementPrice);
            if(settlementPriceList!=null && settlementPriceList.size()>0){
                for (StationSettlementPrice settlementPrice:settlementPriceList){
                    if(settlementPrice.getId()==null){
                        settlementPrice.setCreateBy(currentUser.getUser().getUserId().toString());
                        settlementPrice.setCreateTime(DateUtils.getNowDate());
                        settlementPrice.setSettlementType("1");
                        settlementPrice.setSettlementPrice("0");
                        settlementPrice.setDriverPrice("100");
                        settlementPrice.setStationId(settlementPrice.getDeptId());
                        stationSettlementPriceService.insertStationSettlementPrice(settlementPrice);
                    }
                }
            }
            pircelist = stationSettlementPriceService.selectStationSettlementPriceList(stationSettlementPrice);
        }
        return getTable(pircelist);
    }

    /**
     * 导出结算价格，司机价格列表
     */

    @Log(title = "结算价格，司机价格", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(StationSettlementPrice stationSettlementPrice)
    {
        List<StationSettlementPrice> list = stationSettlementPriceService.selectStationSettlementPriceList(stationSettlementPrice);
        ExcelUtil<StationSettlementPrice> util = new ExcelUtil<StationSettlementPrice>(StationSettlementPrice.class);
        return util.exportExcel(list, "价格");
    }

    /**
     * 获取结算价格，司机价格详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return AjaxResult.success(stationSettlementPriceService.selectStationSettlementPriceById(id));
    }

    /**
     * 新增结算价格，司机价格
     */
    @Log(title = "结算价格，司机价格", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StationSettlementPrice stationSettlementPrice)
    {
        return toAjax(stationSettlementPriceService.insertStationSettlementPrice(stationSettlementPrice));
    }

    /**
     * 修改结算价格，司机价格
     */
    @Log(title = "结算价格，司机价格", businessType = BusinessType.UPDATE)
    @PutMapping
    @Transactional
    public AjaxResult edit(@RequestBody StationSettlementPrice stationSettlementPrice)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        //客户修改数据
        int i = 0;
        if(stationSettlementPrice!=null){
            StationSettlementPriceAdjust stationSettlementPriceAdjust =new StationSettlementPriceAdjust();
            stationSettlementPriceAdjust.setStationId(stationSettlementPrice.getStationId());
            stationSettlementPriceAdjust.setCreateBy(currentUser.getUser().getUserId().toString());
            stationSettlementPriceAdjust.setCreateTime(DateUtils.getNowDate());
            stationSettlementPriceAdjust.setSettlementPrice(stationSettlementPrice.getSettlementPrice());
            stationSettlementPriceAdjust.setDriverPrice(stationSettlementPrice.getDriverPrice());
            stationSettlementPriceAdjust.setSettlementType(stationSettlementPrice.getSettlementType());
            stationSettlementPriceAdjust.setParentId(stationSettlementPrice.getId());
           i= stationSettlementPriceAdjustService.insertStationSettlementPriceAdjust(stationSettlementPriceAdjust);
            stationSettlementPrice.setUpdateBy(currentUser.getUser().getUserId().toString());
            stationSettlementPrice.setUpdateTime(DateUtils.getNowDate());
            i=  stationSettlementPriceService.updateStationSettlementPrice(stationSettlementPrice);
        }
        return toAjax(i);
    }

    /**
     * 删除结算价格，司机价格
     */
    @Log(title = "结算价格，司机价格", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(stationSettlementPriceService.deleteStationSettlementPriceByIds(ids));
    }
}
