package com.yijia.station.service.impl;

import java.util.List;
import com.yijia.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.station.mapper.StationBalanceChangeMapper;
import com.yijia.station.domain.StationBalanceChange;
import com.yijia.station.service.IStationBalanceChangeService;

/**
 * LNG油站余额变化记录Service业务层处理
 * 
 * @author yijia
 * @date 2021-07-13
 */
@Service
public class StationBalanceChangeServiceImpl implements IStationBalanceChangeService 
{
    @Autowired
    private StationBalanceChangeMapper stationBalanceChangeMapper;

    /**
     * 查询LNG油站余额变化记录
     * 
     * @param id LNG油站余额变化记录ID
     * @return LNG油站余额变化记录
     */
    @Override
    public StationBalanceChange selectStationBalanceChangeById(Long id)
    {
        return stationBalanceChangeMapper.selectStationBalanceChangeById(id);
    }

    /**
     * 查询LNG油站余额变化记录列表
     * 
     * @param stationBalanceChange LNG油站余额变化记录
     * @return LNG油站余额变化记录
     */
    @Override
    public List<StationBalanceChange> selectStationBalanceChangeList(StationBalanceChange stationBalanceChange)
    {
        return stationBalanceChangeMapper.selectStationBalanceChangeList(stationBalanceChange);
    }

    /**
     * 新增LNG油站余额变化记录
     * 
     * @param stationBalanceChange LNG油站余额变化记录
     * @return 结果
     */
    @Override
    public int insertStationBalanceChange(StationBalanceChange stationBalanceChange)
    {
        stationBalanceChange.setCreateTime(DateUtils.getNowDate());
        return stationBalanceChangeMapper.insertStationBalanceChange(stationBalanceChange);
    }

    /**
     * 修改LNG油站余额变化记录
     * 
     * @param stationBalanceChange LNG油站余额变化记录
     * @return 结果
     */
    @Override
    public int updateStationBalanceChange(StationBalanceChange stationBalanceChange)
    {
        return stationBalanceChangeMapper.updateStationBalanceChange(stationBalanceChange);
    }

    /**
     * 批量删除LNG油站余额变化记录
     * 
     * @param ids 需要删除的LNG油站余额变化记录ID
     * @return 结果
     */
    @Override
    public int deleteStationBalanceChangeByIds(Long[] ids)
    {
        return stationBalanceChangeMapper.deleteStationBalanceChangeByIds(ids);
    }

    /**
     * 删除LNG油站余额变化记录信息
     * 
     * @param id LNG油站余额变化记录ID
     * @return 结果
     */
    @Override
    public int deleteStationBalanceChangeById(Long id)
    {
        return stationBalanceChangeMapper.deleteStationBalanceChangeById(id);
    }
}
