package com.yijia.station.service.impl;

import java.util.List;
import com.yijia.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.station.mapper.StationSettlementPriceAdjustMapper;
import com.yijia.station.domain.StationSettlementPriceAdjust;
import com.yijia.station.service.IStationSettlementPriceAdjustService;

/**
 * 结算价格，司机价格优惠调整Service业务层处理
 * 
 * @author yijia
 * @date 2021-07-14
 */
@Service
public class StationSettlementPriceAdjustServiceImpl implements IStationSettlementPriceAdjustService 
{
    @Autowired
    private StationSettlementPriceAdjustMapper stationSettlementPriceAdjustMapper;

    /**
     * 查询结算价格，司机价格优惠调整
     * 
     * @param id 结算价格，司机价格优惠调整ID
     * @return 结算价格，司机价格优惠调整
     */
    @Override
    public StationSettlementPriceAdjust selectStationSettlementPriceAdjustById(Integer id)
    {
        return stationSettlementPriceAdjustMapper.selectStationSettlementPriceAdjustById(id);
    }

    /**
     * 查询结算价格，司机价格优惠调整列表
     * 
     * @param stationSettlementPriceAdjust 结算价格，司机价格优惠调整
     * @return 结算价格，司机价格优惠调整
     */
    @Override
    public List<StationSettlementPriceAdjust> selectStationSettlementPriceAdjustList(StationSettlementPriceAdjust stationSettlementPriceAdjust)
    {
        return stationSettlementPriceAdjustMapper.selectStationSettlementPriceAdjustList(stationSettlementPriceAdjust);
    }

    /**
     * 新增结算价格，司机价格优惠调整
     * 
     * @param stationSettlementPriceAdjust 结算价格，司机价格优惠调整
     * @return 结果
     */
    @Override
    public int insertStationSettlementPriceAdjust(StationSettlementPriceAdjust stationSettlementPriceAdjust)
    {
        stationSettlementPriceAdjust.setCreateTime(DateUtils.getNowDate());
        return stationSettlementPriceAdjustMapper.insertStationSettlementPriceAdjust(stationSettlementPriceAdjust);
    }

    /**
     * 修改结算价格，司机价格优惠调整
     * 
     * @param stationSettlementPriceAdjust 结算价格，司机价格优惠调整
     * @return 结果
     */
    @Override
    public int updateStationSettlementPriceAdjust(StationSettlementPriceAdjust stationSettlementPriceAdjust)
    {
        return stationSettlementPriceAdjustMapper.updateStationSettlementPriceAdjust(stationSettlementPriceAdjust);
    }

    /**
     * 批量删除结算价格，司机价格优惠调整
     * 
     * @param ids 需要删除的结算价格，司机价格优惠调整ID
     * @return 结果
     */
    @Override
    public int deleteStationSettlementPriceAdjustByIds(Integer[] ids)
    {
        return stationSettlementPriceAdjustMapper.deleteStationSettlementPriceAdjustByIds(ids);
    }

    /**
     * 删除结算价格，司机价格优惠调整信息
     * 
     * @param id 结算价格，司机价格优惠调整ID
     * @return 结果
     */
    @Override
    public int deleteStationSettlementPriceAdjustById(Integer id)
    {
        return stationSettlementPriceAdjustMapper.deleteStationSettlementPriceAdjustById(id);
    }
}
