package com.yijia.station.service.impl;

import java.util.List;
import com.yijia.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.station.mapper.StationSettlementPriceMapper;
import com.yijia.station.domain.StationSettlementPrice;
import com.yijia.station.service.IStationSettlementPriceService;

/**
 * 结算价格，司机价格Service业务层处理
 * 
 * @author yijia
 * @date 2021-07-13
 */
@Service
public class StationSettlementPriceServiceImpl implements IStationSettlementPriceService 
{
    @Autowired
    private StationSettlementPriceMapper stationSettlementPriceMapper;

    /**
     * 查询结算价格，司机价格
     * 
     * @param id 结算价格，司机价格ID
     * @return 结算价格，司机价格
     */
    @Override
    public StationSettlementPrice selectStationSettlementPriceById(Integer id)
    {
        return stationSettlementPriceMapper.selectStationSettlementPriceById(id);
    }

    /**
     * 查询结算价格，司机价格列表
     * 
     * @param stationSettlementPrice 结算价格，司机价格
     * @return 结算价格，司机价格
     */
    @Override
    public List<StationSettlementPrice> selectStationSettlementPriceList(StationSettlementPrice stationSettlementPrice)
    {
        return stationSettlementPriceMapper.selectStationSettlementPriceList(stationSettlementPrice);
    }

    /**
     * 新增结算价格，司机价格
     * 
     * @param stationSettlementPrice 结算价格，司机价格
     * @return 结果
     */
    @Override
    public int insertStationSettlementPrice(StationSettlementPrice stationSettlementPrice)
    {
        stationSettlementPrice.setCreateTime(DateUtils.getNowDate());
        return stationSettlementPriceMapper.insertStationSettlementPrice(stationSettlementPrice);
    }

    /**
     * 修改结算价格，司机价格
     * 
     * @param stationSettlementPrice 结算价格，司机价格
     * @return 结果
     */
    @Override
    public int updateStationSettlementPrice(StationSettlementPrice stationSettlementPrice)
    {
        stationSettlementPrice.setUpdateTime(DateUtils.getNowDate());
        return stationSettlementPriceMapper.updateStationSettlementPrice(stationSettlementPrice);
    }

    /**
     * 批量删除结算价格，司机价格
     * 
     * @param ids 需要删除的结算价格，司机价格ID
     * @return 结果
     */
    @Override
    public int deleteStationSettlementPriceByIds(Integer[] ids)
    {
        return stationSettlementPriceMapper.deleteStationSettlementPriceByIds(ids);
    }

    /**
     * 删除结算价格，司机价格信息
     * 
     * @param id 结算价格，司机价格ID
     * @return 结果
     */
    @Override
    public int deleteStationSettlementPriceById(Integer id)
    {
        return stationSettlementPriceMapper.deleteStationSettlementPriceById(id);
    }
}
